@@ -1,23 +1,20 @@
 /*
- *   This file is part of the KTeaTime application.
+ * Copyright 1998-1999 by Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
+ * Copyright 2002-2003 by Martin Willers <willers@xm-arts.de>
+ * Copyright 2007-2009 by Stefan Böhmann <kde@hilefoks.org>
  *
- *   Copyright (C) 1998-1999  Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
- *   Copyright (C) 2002-2003  Martin Willers <willers@xm-arts.de>
- *   Copyright (c) 2007-2009  Stefan Böhmann <kde@hilefoks.org>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "toplevel.h"
 #include "timeedit.h"
@@ -47,8 +44,6 @@ TopLevel::TopLevel(const KAboutData *aboutData, const QString &icon, QWidget *pa
     m_icon( loadIcon( icon ) ),
     m_pix( loadIcon( icon ).pixmap( QSize( 22, 22 ) ) )
 {
-    QApplication::setQuitOnLastWindowClosed( false );
-
     KSharedConfigPtr config = KSharedConfig::openConfig();
     KConfigGroup tealistGroup( config, "Tealist" );
 
@@ -273,11 +268,8 @@ void TopLevel::teaTimeEvent()
         if( m_usepopup ) {
             showMessage( title, content, QSystemTrayIcon::Information, m_autohide ? m_autohidetime*1000 : 2100000000 );
         }
-
-        if( m_usenotification ) {
-            KNotification::event( "ready", content, m_pix );
-        }
-
+        
+        KNotification::event( "ready", content, m_pix );
 
         if( m_usereminder && m_remindertime > 0 ) {
             m_popup->setView( title, content, m_pix );
@@ -300,10 +292,8 @@ void TopLevel::teaTimeEvent()
                 showMessage( title, content, QSystemTrayIcon::Information, m_autohide ? m_autohidetime*1000 : 2100000000 );
             }
 
-            if( m_usenotification ) {
-                KNotification::event( "reminder", content, m_pix );
-            }
-
+            KNotification::event( "reminder", content, m_pix );
+ 
             m_nextNotificationTime -= m_remindertime;
         }
         --m_runningTeaTime;
@@ -337,7 +327,6 @@ void TopLevel::loadConfig()
     KSharedConfigPtr config = KSharedConfig::openConfig();
     KConfigGroup generalGroup( config, "General" );
 
-    m_usenotification=generalGroup.readEntry( "UseNotification", true );
     m_usepopup=generalGroup.readEntry( "UsePopup", true );
     m_autohide=generalGroup.readEntry( "PopupAutoHide", false );
     m_autohidetime=generalGroup.readEntry( "PopupAutoHideTime", 30 );
